Error

Enum Error 

pub enum Error {
Show 31 variants PathInaccessible(PathBuf), PathReadonly(PathBuf), NotADirectory(PathBuf), DirectoryCreationFailed(PathBuf, String), EmptyName, PlayerNotConnected, StateNotInitialized, QueueEmpty, SourceError, PlayerPlaying, PlayerPaused, PlayerStopped, SeekNotSupported, CannotGoPrevious, CannotGoNext, NoTrackAtIndex(usize), InvalidDuration, DurationOverflow, PlaylistExists, LibraryNotInitialized, UnknownPlaylist(String), IndexOutOfBounds, DuplicateItems, UnknownTrack, StateNotReadable, StateWriteFailed, StateNotAFile, PathDoesNotExist, DirectoryWithNoTracks, PlaylistParsingError, PlaylistExportFailed,
}
Chilen error type.

Variants



PathInaccessible(PathBuf)



PathReadonly(PathBuf)



NotADirectory(PathBuf)



DirectoryCreationFailed(PathBuf, String)



EmptyName



PlayerNotConnected

The audio player is not connected.

This may happen if the device doesn’t have an audio device or none of the audio devices are marked as default.



StateNotInitialized

The playback state is not initialized.



QueueEmpty

The queue is empty.



SourceError

The audio file could not be opened, has an unsupported format or is corrupt.



PlayerPlaying

The player is already playing.



PlayerPaused

The player is already paused.



PlayerStopped

Thrown when a client attempts to stop the player when it was already stopped or when a client attempts to seek while the player is stopped.



SeekNotSupported

Seek is not supported for the current audio source.



CannotGoPrevious

Cannot go to the previous track.

This means that the current track is first in the queue and the loop state is set to LoopState::Off.



CannotGoNext

Cannot go to the next track.

This means that the current track is last in the queue and the loop state is set to LoopState::Off.



NoTrackAtIndex(usize)

No track at this index.



InvalidDuration

The player position could not be set because the duration provided was invalid.

The player will additionally refuse to seek by 0s to prevent audio popping.



DurationOverflow

Overflow detected while performing a seek operation.



PlaylistExists

Could not complete the operation because a playlist with the provided name already exists.



LibraryNotInitialized

Could not perform the operation because the music library is not initialized.

This can happen if a command is sent to early and the music library is not yet initialized.



UnknownPlaylist(String)

There is no playlist in the music library with the provided name.



IndexOutOfBounds

The provided item index was out of bounds.



DuplicateItems

The provided list contained duplicate values.



UnknownTrack

The provided track is not registered in the library.



StateNotReadable

Could not read the contents of the library state file.



StateWriteFailed

Could not write the library state to a file.



StateNotAFile

The library state path is not a file.



PathDoesNotExist

The provided path does not exist or access to it was denied.



DirectoryWithNoTracks

Could not find any audio files in the provided directory path.



PlaylistParsingError

Could not parse the M3U8 playlist.

Please make sure that the playlist has the correct format and is not corrupted.



PlaylistExportFailed

Could not export the playlist to M3U8.

This likely either means that the specified file path doesn’t exists or is not writable.