pub struct Config {
pub identity: String,
pub identifier: String,
pub cache_dir: PathBuf,
pub music_dir: PathBuf,
pub data_dir: PathBuf,
pub locale: Locale,
pub playback: Config,
pub library: Config,
}Fields
identity: StringA friendly name to identify the media player to users (eg: “VLC media player”).
identifier: StringThe bus name suffix to be used with MPRIS.
The resulting bus name will be org.mpris.MediaPlayer2.<bus_name_suffix>, where
<bus_name_suffix> must be a unique identifier, such as one based on a UNIX process id.
For example, this could be:
org.mpris.MediaPlayer2.vlc.instance7389
Note: According to the D-Bus specification, the unique identifier “must only contain the ASCII characters [A-Z][a-z][0-9]_-” and “must not begin with a digit”.
cache_dir: PathBufmusic_dir: PathBufdata_dir: PathBuflocale: Localeplayback: Configlibrary: ConfigTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Config
impl<'de> Deserialize<'de> for Config
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Config
impl StructuralPartialEq for Config